@@ -11,12 +11,13 @@ class SQLBuilder(object):
     types, unique key and foreign key contraints.
     """
     def __init__(self, table_name, cols_names, cols_types, unique_key=None,
-                 foreign_keys=None):
+                 foreign_keys=None, keys=None):
         self.table_name = table_name
         self.cols_names = cols_names
         self.cols_types = cols_types
         self.unique_key = unique_key
         self.foreign_keys = foreign_keys
+        self.keys = keys
         self.query = self._get_query()
 
     def _get_query(self):
@@ -35,11 +36,12 @@ class SQLBuilder(object):
             template_contents = sql_file.read()
 
         template = Template(template_contents, trim_blocks=True)
-
+        
         rendered_template =  template.render(
             table_name = self.table_name,
             columns = columns,
             unique_key = self.unique_key,
-            foreign_keys = self.foreign_keys)
+            foreign_keys = self.foreign_keys,
+            keys = self.keys)
 
         return rendered_template
